@@ -8,7 +8,7 @@ from magplan.models import Issue, User
 @login_required
 def issues_search(request):
     q = request.GET.get('q', None)
-    issues = Issue.objects.filter(number__exact=q)
+    issues = Issue.on_current_site.filter(number__exact=q)
     return JsonResponse(
         [{'id': issue.id, 'text': issue.__str__()} for issue in issues]
         , safe=False)
